msgid(LANG_NATIVE_NAME)
msgstr("Polski")

msgid(LANG_ENGLISH_NAME)
msgstr("Polish")


/******************************************************************************
 *** Splash Message & Change Log                                            ***
 ******************************************************************************/
msgid(SPLASH_TITLE)
msgstr("Witaj w nowym uTox!")

msgid(SPLASH_TEXT)
msgstr("uTox został zaktualizowany do wersji 0.9.8! Nazwa kodowa wersji: Srsly v3")

msgid(CHANGE_LOG_TITLE)
msgstr("Zmiany w v0.9.8")

msgid(CHANGE_LOG_TEXT)
msgstr(
"    Usunięto błąd podczas tworzenia nowego profilu\n"
"\nv0.9.7\n"
"    Usprawniono interfejs użytkownika \n"
"    Zamieniono wszystkie listy Tak/Nie na przełączniki\n"
"    Naprawiono zapisywanie hostów proxy i portów podczas restartów.\n"
"\nv0.9.5\n"
"    Wideo w środku okna dla OSX\n"
"    Usunięto błąd zapisywania historii\n"
"\nv0.9.3\n"
"    Usunięto błąd z wiadomościami który powodował sporadyczne awarie w Windows\n"
"    Zmniejszono liczbę wiadomości które można ponownie wysyłać na raz\n"
"\nv0.9.2\n"
"    Poprawiono kod źródłowy/Zmienono ścieżki\n"
"\nv0.9.1\n"
"    Usunięto błąd podczas wysyłania wiadomości do nowego znajomego\n"
"\nv0.9.0\n"
"   Kolejka wiadomości\n"
"   Poprawiono czaty grupowe\n"
"   Eksperymentalna funkcja wideo w środku okna\n"
"   Mała lista kontaktów\n"
"   Usprawniono przetwarzanie wiadomości\n"
"\n")

/******************************************************************************
 *** MISC & UNSORTED                                                        ***
 ******************************************************************************/

msgid(REQ_SENT)
msgstr("Wysłano zaproszenie do znajomego. Znajomy stanie się dostępny po jego przyjęciu")

msgid(REQ_INVALID_ID)
msgstr("Błąd: Nieprawidłowy Tox ID")

msgid(REQ_ADDED_NO_FREQ_SENT)
msgstr("Uwaga: Dodano znajomego, ale zaproszenie nie zostało wysłane (brakuje nospam)")

msgid(REQ_EMPTY_ID)
msgstr("Błąd: Nie podano Tox ID")

msgid(REQ_LONG_MSG)
msgstr("Błąd: Wiadomość jest za długa")

msgid(REQ_NO_MSG)
msgstr("Błąd: Pusta wiadomość")

msgid(REQ_SELF_ID)
msgstr("Błąd: Próba dodania własnego Tox ID")

msgid(REQ_ALREADY_FRIENDS)
msgstr("Błąd: Podany Tox ID jest już na liście znajomych")

msgid(REQ_UNKNOWN)
msgstr("Błąd: Nieznany")

msgid(REQ_BAD_CHECKSUM)
msgstr("Błąd: Nieprawidłowy Tox ID (zła suma kontrolna)")

msgid(REQ_BAD_NOSPAM)
msgstr("Błąd: Nieprawidłowy Tox ID (zła wartość nospam)")

msgid(REQ_NO_MEMORY)
msgstr("Błąd: Brak pamięci")

msgid(SEND_FILE)
msgstr("Wyślij plik")

msgid(SAVE_FILE)
msgstr("Zapisz plik")

msgid(WHERE_TO_SAVE_FILE_PROMPT)
msgstr("Gdzie chcesz zapisać plik \"%.*s\"?")

msgid(WHERE_TO_SAVE_FILE)
msgstr("Gdzie chcesz zapisać plik?")

msgid(SEND_FILE_PROMPT)
msgstr("Wybierz jeden lub więcej plików do wysłania.")

msgid(SCREEN_CAPTURE_PROMPT)
msgstr("Zaznacz część ekranu do przesłania.")


/******************************************************************************
 *** File Transfer Strings                                                  ***
 ******************************************************************************/
msgid(TRANSFER_NEW)
msgstr("Nowy transfer pliku")

msgid(TRANSFER_STARTED)
msgstr("Transfer pliku rozpoczęty")

msgid(TRANSFER_PAUSED)
msgstr("Transfer pliku wstrzymany")

msgid(TRANSFER_BROKEN)
msgstr("Transfer pliku nieudany")

msgid(TRANSFER_CANCELLED)
msgstr("Transfer pliku anulowany")

msgid(TRANSFER_COMPLETE)
msgstr("Transfer pliku zakończony")


/******************************************************************************
 *** Keyboard and Mouse Cursor Strings                                      ***
 ******************************************************************************/
msgid(CURSOR_CLICK_LEFT)
msgstr("Kliknięcie lewym przyciskiem myszy")

msgid(CURSOR_CLICK_RIGHT)
msgstr("Kliknięcie prawym przyciskiem myszy")


/******************************************************************************
 *** Audio / Video Call Strings                                             ***
 ******************************************************************************/
msgid(CALL_START_AUDIO)
msgstr("Rozpocznij rozmowę głosową")

msgid(CALL_START_VIDEO)
msgstr("Rozpocznij rozmowę wideo")

msgid(CALL_DECLINE)
msgstr("Odrzuć połączenie")

msgid(CALL_CANCELLED)
msgstr("Połączenie anulowane")

msgid(CALL_INVITED)
msgstr("Rozmowa przychodząca")

msgid(CALL_RINGING)
msgstr("Dzwonienie")

msgid(CALL_STARTED)
msgstr("Rozmowa rozpoczęta")

msgid(CALL_ENDED)
msgstr("Rozmowa zakończona")

msgid(CALL_FRIEND_HAD_ENDED_CALL)
msgstr(" zakończył rozmowę!")

msgid(CALL_VIDEO_SHOW_INLINE)
msgstr("Pokaż wideo w środku okna")


/******************************************************************************
 *** Friend & Friend Settings Strings                                       ***
 ******************************************************************************/
msgid(FRIEND_ALIAS)
msgstr("Ustaw pseudonim znajomego")

msgid(FRIEND_PUBLIC_KEY)
msgstr("Klucz publiczny znajomego")

msgid(FRIEND_AUTOACCEPT)
msgstr("Akceptuj pliki przychodzące bez potwierdzenia")

msgid(FRIEND_EXPORT_CHATLOG)
msgstr("Eksportuj historię czatu znajomego do pliku tekstowego")


/******************************************************************************
 *** Group Strings                                                          ***
 ******************************************************************************/
msgid(GROUPCHAT_JOIN_AUDIO)
msgstr("Dołącz do grupowej rozmowy audio")

msgid(GROUP_CREATE_WITH_AUDIO)
msgstr("Włącz głos audio")

msgid(GROUP_CREATE_TEXT)
msgstr("Utwórz grupę tekstową")

msgid(GROUP_CREATE_VOICE)
msgstr("Utwórz grupę z rozmową głosową")

msgid(CREATEGROUPCHAT)
msgstr("Utwórz grupę")

msgid(REMOVE_GROUP)
msgstr("Usuń grupę")

msgid(LEAVE_GROUP)
msgstr("Opuść grupę")


/******************************************************************************
 *** Group Settings                                                         ***
 ******************************************************************************/
msgid(GROUPCHAT_SETTINGS)
msgstr("Ustawienia grupy")

msgid(GROUP_NOTIFICATIONS)
msgstr("Powiadomienia o aktywności w grupie")

msgid(GROUP_NOTIFICATIONS_ON)
msgstr("Włączone")

msgid(GROUP_NOTIFICATIONS_MENTION)
msgstr("Tylko przy wspomnieniu o mnie")

msgid(GROUP_NOTIFICATIONS_OFF)
msgstr("Wyłączone")

msgid(GROUP_TOPIC)
msgstr("Ustaw temat grupy")

/******************************************************************************
 *** Settings / Profile Strings                                             ***
 ******************************************************************************/
msgid(PROFILE_BUTTON)
msgstr("Profil")

msgid(DEVICES_BUTTON)
msgstr("Urządzenia")


msgid(USER_INTERFACE_BUTTON)
msgstr("Interfejs użytkownika")

msgid(AUDIO_VIDEO_BUTTON)
msgstr("Audio i Wideo")

msgid(ADVANCED_BUTTON)
msgstr("Zaawansowane")

msgid(NOTIFICATIONS_BUTTON)
msgstr("Powiadomienia")

msgid(PROFILE_SETTINGS)
msgstr("Ustawienia profilu")

msgid(PROFILE_PW_WARNING)
msgstr("UWAGA: µTox zacznie automatycznie szyfrować tym hasłem.")

msgid(PROFILE_PW_NO_RECOVER)
msgstr("Nie ma sposobu by odzyskać utracone hasła.")



/***     	Profile                                                         ***/

/***     	Devices                                                         ***/
msgid(DEVICES_ADD_NEW)
msgstr("Dodaj nowe urządzenie do sieci")

msgid(DEVICES_NUMBER)
msgstr("Lista połączonych urządzeń")
/*** 		Network                                                         ***/

/***    	User Interface                                                  ***/

/***		Audio/Video                                                     ***/



/******************************************************************************
 *** UNSORTED STRINGS                                                       ***
 *** TODO:                                                                  ***
 *** FIXME:                                                                 ***
 ******************************************************************************/
msgid(ADDFRIENDS)
msgstr("Dodaj nowy kontakt")

msgid(MESSAGE)
msgstr("Wiadomość")

msgid(FILTER_ONLINE)
msgstr("Dostępne kontakty")

msgid(FILTER_ALL)
msgstr("Wszystkie kontakty")

msgid(FILTER_CONTACT_TOGGLE)
msgstr("Tylko podłączone kontakty")

msgid(ADD)
msgstr("Dodaj")

msgid(FRIENDREQUEST)
msgstr("Zaproszenie do znajomych")

msgid(USERSETTINGS)
msgstr("Ustawienia profilu")

msgid(FRIEND_SETTINGS)
msgstr("Ustawienia znajomego")

msgid(NAME)
msgstr("Nazwa")

msgid(STATUSMESSAGE)
msgstr("Opis")

msgid(PREVIEW)
msgstr("Podgląd")

msgid(AUDIOINPUTDEVICE)
msgstr("Urządzenie wejściowe audio")

msgid(AUDIOFILTERING)
msgstr("Filtrowanie audio")

msgid(AUDIOOUTPUTDEVICE)
msgstr("Urządzenie wyjściowe audio")

msgid(VIDEOINPUTDEVICE)
msgstr("Urządzenie wejściowe wideo")

msgid(PUSH_TO_TALK)
msgstr("Naciśnij i mów")

msgid(STATUS_ONLINE)
msgstr("Dostępny")

msgid(STATUS_AWAY)
msgstr("Zaraz wracam")

msgid(STATUS_BUSY)
msgstr("Zajęty")

msgid(STATUS_OFFLINE)
msgstr("Niedostępny")

msgid(STATUS_MESSAGE)
msgstr("uTox %.*s zmienił status na %s.")

msgid(SETTINGS_UI_MINI_ROSTER)
msgstr("Użyj małej listy kontaktów")

msgid(NOT_CONNECTED)
msgstr("Niepodłączony")

msgid(OTHERSETTINGS)
msgstr("Inne ustawienia")

msgid(UI)
msgstr("Interfejs")

msgid(USER_INTERFACE)
msgstr("Interfejs użytkownika")

msgid(UTOX_SETTINGS)
msgstr("Ustawienia uTox")

msgid(NETWORK_SETTINGS)
msgstr("Ustawienia sieci")

msgid(PROFILE_PASSWORD)
msgstr("Hasło profilu")

msgid(LOCK_UTOX)
msgstr("Rozłącza z siecią Tox i blokuje ten profil.")

msgid(SHOW_UI_PASSWORD)
msgstr("Wyświetl pole hasła")

msgid(SHOW_UI_PASSWORD_TOOLTIP)
msgstr("Kliknij, aby wyświetlić pole hasła profilu. Zmiany zostaną wprowadzone natychmiastowo!")

msgid(HIDE_UI_PASSWORD)
msgstr("Schowaj pole hasła")

msgid(HIDE_UI_PASSWORD_TOOLTIP)
msgstr("Kliknij, aby schować pole hasła.")

msgid(PASSWORD_TOO_SHORT)
msgstr("Hasło musi mieć co najmniej 4 znaki")

msgid(LOCK)
msgstr("Zablokuj")

msgid(AUDIO_VIDEO)
msgstr("Audio/Wideo")

msgid(SAVELOCATION)
msgstr("Ścieżka zapisywania danych")

msgid(LANGUAGE)
msgstr("Język")

msgid(NETWORK)
msgstr("Sieć")

msgid(PROXY_FORCE)
msgstr("Wymuszaj użycie proxy")

msgid(WARNING)
msgstr("Zmiana ustawień sieci/proxy na chwilę rozłączy Cię z siecią Tox")

msgid(SAVE_CHAT_HISTORY)
msgstr("Zapisuj historię")

msgid(AUDIONOTIFICATIONS)
msgstr("Włącz powiadomienia Audio (dzwonek)")

msgid(RINGTONE)
msgstr("Dzwonek")

msgid(IS_TYPING)
msgstr("pisze...")

msgid(CLOSE_TO_TRAY)
msgstr("Zamknij do zasobnika")

msgid(START_IN_TRAY)
msgstr("Uruchom w zasobniku")

msgid(SHOW_QR)
msgstr("Wyświetl kod QR")

msgid(HIDE_QR)
msgstr("Schowaj kod QR")

msgid(SAVE_QR)
msgstr("Zapisz kod QR")

msgid(COPY_TOX_ID)
msgstr("Kopiuj jako tekst")

msgid(COPY)
msgstr("Kopiuj")

msgid(COPYWITHOUTNAMES)
msgstr("Kopiuj (bez nazw)")

msgid(COPY_WITH_NAMES)
msgstr("Kopiuj (z nazwami)")

msgid(CUT)
msgstr("Wytnij")

msgid(PASTE)
msgstr("Wklej")

msgid(DELETE)
msgstr("Usuń")

msgid(SELECTALL)
msgstr("Zaznacz wszystko")

msgid(REMOVE)
msgstr("Usuń")

msgid(REMOVE_FRIEND)
msgstr("Usuń znajomego")

msgid(LEAVE)
msgstr("Opuść")

msgid(CTOPIC)
msgstr("Zmień temat")

msgid(ACCEPT)
msgstr("Akceptuj")

msgid(IGNORE)
msgstr("Ignoruj")

msgid(SET_ALIAS)
msgstr("Ustaw pseudonim")

msgid(ALIAS)
msgstr("Pseudonim")

msgid(SENDMESSAGE)
msgstr("Wyślij wiadomość")

msgid(SENDSCREENSHOT)
msgstr("Wyślij zrzut ekranu")

msgid(CLICKTOSAVE)
msgstr("Kliknij, aby zapisać")

msgid(CLICKTOOPEN)
msgstr("Kliknij, aby otworzyć")

msgid(CANCELLED)
msgstr("Anulowano")

msgid(DPI_060)
msgstr("Niestandardowe DPI 60%")

msgid(DPI_070)
msgstr("Niestandardowe DPI 70%")

msgid(DPI_080)
msgstr("Niestandardowe DPI 80%")

msgid(DPI_090)
msgstr("Niestandardowe DPI 90%")

msgid(DPI_100)
msgstr("Niestandardowe DPI 100%")

msgid(DPI_110)
msgstr("CNiestandardowe DPI 110%")

msgid(DPI_120)
msgstr("Niestandardowe DPI 120%")

msgid(DPI_130)
msgstr("Niestandardowe DPI 130%")

msgid(DPI_140)
msgstr("Niestandardowe DPI 140%")

msgid(DPI_150)
msgstr("Niestandardowe DPI 150%")

msgid(DPI_160)
msgstr("Niestandardowe DPI 160%")

msgid(DPI_170)
msgstr("Niestandardowe DPI 170%")

msgid(DPI_180)
msgstr("Niestandardowe DPI 180%")

msgid(DPI_190)
msgstr("Niestandardowe DPI 190%")

msgid(DPI_200)
msgstr("Niestandardowe DPI 200%")

msgid(DPI_210)
msgstr("Niestandardowe DPI 210%")

msgid(DPI_220)
msgstr("Niestandardowe DPI 220%")

msgid(DPI_230)
msgstr("Niestandardowe DPI 230%")

msgid(DPI_240)
msgstr("Niestandardowe DPI 240%")

msgid(DPI_250)
msgstr("Niestandardowe DPI 250%")

msgid(DPI_260)
msgstr("Niestandardowe DPI 260%")

msgid(DPI_270)
msgstr("Niestandardowe DPI 270%")

msgid(DPI_280)
msgstr("Niestandardowe DPI 280%")

msgid(DPI_290)
msgstr("Niestandardowe DPI 290%")

msgid(DPI_300)
msgstr("Niestandardowe DPI 300%")

msgid(DPI_TINY)
msgstr("Małe (50%)")

msgid(DPI_NORMAL)
msgstr("Normalne (100%)")

msgid(DPI_BIG)
msgstr("Duże (150%)")

msgid(DPI_LARGE)
msgstr("Wielkie (200%)")

msgid(DPI_HUGE)
msgstr("Ogromne (250%)")

msgid(PROXY_DISABLED)
msgstr("Wyłączone")

msgid(PROXY_FALLBACK)
msgstr("Zapasowe")

msgid(PROXY_ALWAYS_USE)
msgstr("Zawsze używaj")

msgid(NO)
msgstr("Nie")

msgid(YES)
msgstr("Tak")

msgid(OFF)
msgstr("Wyłączone")

msgid(ON)
msgstr("Włączone")

msgid(SHOW)
msgstr("Pokaż")

msgid(HIDE)
msgstr("Ukryj")

msgid(EXIT)
msgstr("Zakończ")

msgid(VIDEO_IN_NONE)
msgstr("Brak")

msgid(VIDEO_IN_DESKTOP)
msgstr("Pulpit")

msgid(AUDIO_IN_DEFAULT_LOOPBACK)
msgstr("Domyślny Loopback")

msgid(AUDIO_IN_ANDROID)
msgstr("Wejście OpenSL")

msgid(DEFAULT_FRIEND_REQUEST_MESSAGE)
msgstr("Proszę, zaakceptuj to zaproszenie do znajomych.")

msgid(CONTACT_SEARCH_ADD_HINT)
msgstr("Szukaj/dodaj znajomych")

msgid(PROXY_EDIT_HINT_IP)
msgstr("Adres IP")

msgid(WINDOW_TITLE_VIDEO_PREVIEW)
msgstr("Podgląd wideo")

msgid(MUTE)
msgstr("Wycisz")

msgid(UNMUTE)
msgstr("Wyłącz wyciszenie")

msgid(SELECT_AVATAR_TITLE)
msgstr("Wybierz awatar")

msgid(AVATAR_TOO_LARGE_MAX_SIZE_IS)
msgstr("Awatar zbyt duży. Rozmiar maksymalny to: ")

msgid(CANT_FIND_FILE_OR_EMPTY)
msgstr("Nie można znaleźć wybranego pliku lub wybrany plik jest pusty.")

msgid(CLEAR_HISTORY)
msgstr("Wyczyść historię")

msgid(AUTO_STARTUP)
msgstr("Uruchamiaj wraz ze startem systemu")

msgid(THEME)
msgstr("Motyw")

msgid(THEME_DEFAULT)
msgstr("Domyślny")

msgid(THEME_LIGHT)
msgstr("Jasny")

msgid(THEME_DARK)
msgstr("Ciemny")

msgid(THEME_HIGHCONTRAST)
msgstr("Wysoki kontrast")

msgid(THEME_CUSTOM)
msgstr("Własny (zobacz dokumentację)")

msgid(SEND_TYPING_NOTIFICATIONS)
msgstr("Wysyłaj powiadomienia gdy piszę")

msgid(STATUS_NOTIFICATIONS)
msgstr("Powiadomienia o zmianach statusu")

msgid(RANDOMIZE_NOSPAM)
msgstr("Losuj Nospam")

msgid(REVERT_NOSPAM)
msgstr("Przywróć Nospam")

msgid(NOSPAM_WARNING)
msgstr("Zmiana Twojego nospam spowoduje, że Twoje Tox ID przestanie działać. uTox nie aktualizuje ID na serwerach nazw.")

msgid(BLOCK_FRIEND_REQUESTS)
msgstr("Blokuj zaproszenia do znajomych")

msgid(SHOW_NOSPAM)
msgstr("Pokaż ustawienia nospam")

msgid(HIDE_NOSPAM)
msgstr("Schowaj ustawienia nospam")

msgid(DELETE_FRIEND)
msgstr("Usuń znajomego")

msgid(DELETE_MESSAGE)
msgstr("Jesteś pewien, że chcesz skasować ")

msgid(KEEP)
msgstr("Zatrzymaj")
